<!DOCTYPE html>
<html>
<head>
    <link rel="icon" type="image/png" href="image/logo-icon.png" />
    <title>Client Data — CA Subham Dubey</title>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="Client data acquisition form">
    <meta name="keywords" content="CA services, client data">
    
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css">
    <link rel="stylesheet" href="css/style.css">
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script type="text/javascript" src="js/script.js"></script>
</head>
<body>
    <?php include "configuration.php"; ?>
    <?php include "header.php"; ?>
    
    <div class="h-container-screen-inside">
        <div class="h-content-screen-inside">
            <div class="h-heading-screen-inside">Client Data Acquisition</div>
        </div>
    </div>
    
    <div class="h-container-form">
        <div class="h-content-form">
            <?php echo $description ?? ''; ?>
            <form id="client_data_form" method="post" enctype="multipart/form-data">
                <div class="h-input-set">
                    <label for="service_required">Service Required</label>
                    <select name="service_required" id="service_required" required>
                        <option value="">Select Service</option>
                        <option value="INCOME_TAX">Income Tax</option>
                        <option value="DSC">Digital Signature Certificate (DSC)</option>
                        <option value="FSSAI">FSSAI License</option>
                        <option value="TAN">TAN Number</option>
                        <option value="GST">GST Registration</option>
                        <option value="COMPANY">Company Registration</option>
                        <option value="PARTNERSHIP">Partnership Firm Registration</option>
                        <option value="SOLE_PROP">Sole Proprietorship</option>
                    </select>
                </div>

                <div class="h-input-set">
                    <label for="name">Name</label>
                    <input type="text" name="name" id="name" required class="h-input-text">
                </div>

                <div class="h-input-set">
                    <label for="phone">Phone</label>
                    <table>
                        <tr>
                            <td class="h-phone-country">
                                <select class="h-input-select" name="phone_country" id="phone_country">
                                    <option value="+91">+91</option>
                                </select>    
                            </td>
                            <td><input type="tel" name="phone" id="phone" required class="h-input-text" pattern="[0-9]{10}"></td>
                        </tr>
                    </table>
                </div>

                <div class="h-input-set">
                    <label for="message">Message (optional)</label>
                    <textarea name="message" id="message" class="h-input-text"></textarea>
                </div>

                <!-- File Upload Sections -->
                <div class="file-upload-sections">
                    <div id="income_tax_files" class="file-upload-section" style="display: none;">
                        <h3>Required Documents for Income Tax</h3>
                        <input type="file" name="income_tax[bank_statements]" accept=".pdf,.jpg,.jpeg,.png"> Bank Statements<br>
                        <input type="file" name="income_tax[pan_card]" accept=".pdf,.jpg,.jpeg,.png"> PAN Card<br>
                        <input type="file" name="income_tax[aadhaar_card]" accept=".pdf,.jpg,.jpeg,.png"> Aadhaar Card<br>
                    </div>

                    <div id="dsc_files" class="file-upload-section" style="display: none;">
                        <h3>Required Documents for DSC</h3>
                        <input type="file" name="dsc[pan_card]" accept=".pdf,.jpg,.jpeg,.png"> PAN Card<br>
                        <input type="file" name="dsc[aadhaar_card]" accept=".pdf,.jpg,.jpeg,.png"> Aadhaar Card<br>
                        <input type="file" name="dsc[passport_photo]" accept=".jpg,.jpeg,.png"> Passport-size Photo<br>
                        <input type="file" name="dsc[gst_certificate]" accept=".pdf,.jpg,.jpeg,.png"> GST Certificate<br>
                        <input type="file" name="dsc[partnership_deed]" accept=".pdf"> Partnership Deed (if applicable)<br>
                    </div>

                    <!-- Add other file sections similarly with unique array names -->
                </div>

                <p><input type="submit" value="Submit" id="save" class="h-button-form"></p>
            </form>
        </div>
    </div>
    
    <?php include "footer.php"; ?>
    <div id="h_shield" style="display: none;"></div>

    <script>
    $(document).ready(function(){
        function toggleFileSections() {
            const service = $("#service_required").val();
            $(".file-upload-section").hide();
            if (service) {
                $(`#${service.toLowerCase()}_files`).show();
            }
        }

        $("#service_required").change(toggleFileSections);
        toggleFileSections();

        $("#client_data_form").on('submit', function(e){
            e.preventDefault();
            const formData = new FormData(this);
            
            // Debug form data
            console.log('Submitting form with data:');
            for (let [key, value] of formData.entries()) {
                console.log(`${key}: ${value instanceof File ? value.name : value}`);
            }

            $.ajax({
                type: 'POST',
                url: 'client-data-save.php',
                data: formData,
                dataType: 'json',
                contentType: false,
                cache: false,
                processData: false,
                beforeSend: function(){
                    $("#h_shield").show();
                },
                success: function(response){
                    $("#h_shield").hide();
                    console.log('Server response:', response);
                    if(response.success){
                        window.location.href = 'https://www.masterhub.work/p/casubhamdubey/client-data-sent.php';
                    } else {
                        alert('Upload failed: ' + (response.errors ? 
                            Object.values(response.errors).join('\n') : 'Unknown error'));
                    }
                },
                error: function(xhr, status, error){
                    $("#h_shield").hide();
                    console.error('AJAX Error:', xhr.responseText);
                    alert('Submission failed: ' + xhr.responseText);
                }
            });
        });
    });
    </script>
</body>
</html>